@@ -85,7 +85,7 @@ freepops.MODULES_MAP["yahoo.fr"]        = {name="yahoo.lua"}
 freepops.MODULES_MAP["rocketmail.com"]  = {name="yahoo.lua"}
 freepops.MODULES_MAP["talk21.com"]  = {name="yahoo.lua"}
 freepops.MODULES_MAP["btinternet.com"]  = {name="yahoo.lua"}
- 
+freepops.MODULES_MAP["ymail.com"]  = {name="yahoo.lua"}
 
 -- hotmail
 freepops.MODULES_MAP["hotmail.com"]		= {name="hotmail.lua"}
@@ -110,6 +110,7 @@ freepops.MODULES_MAP["live.it"]		= {name="hotmail.lua"}
 freepops.MODULES_MAP["live.nl"]		= {name="hotmail.lua"}
 freepops.MODULES_MAP["live.co.uk"]		= {name="hotmail.lua"}
 freepops.MODULES_MAP["live.com.au"]		= {name="hotmail.lua"}
+freepops.MODULES_MAP["milanosemplice.it"] = {name="hotmail.lua"}
 
 -- aol
 freepops.MODULES_MAP["aol.com"]		= {name="aol.lua"}
