@@ -1,10 +1,17 @@
 -- this is not the origina http.lua, since it was luasocket-based
 -- this file is released under the same license as LUA 5.0 (MIT)
 
+MODULE_VERSION = "0.0.2"
+MODULE_NAME = "soap.http"
+MODULE_REQUIRE_VERSION = "0.2.0"
+MODULE_LICENSE = "GNU/GPL"
+MODULE_URL = "http://www.freepops.org/download.php?module=soap.http.lua"
+MODULE_HOMEPAGE = "http://www.freepops.org/"
+
 require("browser") 
 require("soap")
 
-module("soap.http")
+module("soap.http", package.seeall)
 
 function call(browser, url, namespace, method, entries, headers)
 	local rc, err = 
