@@ -1,5 +1,5 @@
 /******************************************************************************
- * $Id: mlex.c,v 1.7 2005/10/24 22:43:58 gareuselesinge Exp $
+ * $Id: mlex.c,v 1.10 2007/06/22 15:10:38 gareuselesinge Exp $
  * This file is part of liberopops (http://liberopops.sf.net)                 *
  * This file is distributed under the terms of GNU GPL license.               *
  ******************************************************************************/
@@ -266,7 +266,7 @@ p->end = pos+1;
 HIDDEN list_t *tokenize_html(char* t)
 {
 list_t * l = NULL,*tl=NULL;
-int position=0;
+unsigned int position=0;
 regmatch_t p[1];
 unsigned int len = strlen(t);
 
@@ -393,6 +393,9 @@ regmatch_t p;
 tmp=s[t->stop];
 s[t->stop]='\0';
 p=regfind(&s[t->start],exp);
+#ifdef DEBUG_MLEX
+printf("Regfind '%s' on '%s' is %d\n",exp,&s[t->start],p.begin);
+#endif
 s[t->stop]=tmp;
 return p;
 }
