@@ -1,5 +1,5 @@
 /******************************************************************************
- * $Id: win32_compatibility.c,v 1.3 2007/01/13 22:36:24 gareuselesinge Exp $
+ * $Id: win32_compatibility.c,v 1.4 2008/06/04 22:58:37 gareuselesinge Exp $
  * This file is part of liberopops (http://liberopops.sf.net)                 *
  * This file is distributed under the terms of GNU GPL license.               *
  ******************************************************************************/
@@ -71,7 +71,7 @@ return NULL;
 }
 #endif
 
-int inet_aton(const char *cp, struct in_addr *inp){
+int inet_aton_w32(const char *cp, struct in_addr *inp){
 inp->s_addr = inet_addr(cp);
 return inp->s_addr != -1;
 }
