@@ -1,5 +1,5 @@
 /******************************************************************************
- * $Id: win32_compatibility.h,v 1.3 2007/01/13 22:36:24 gareuselesinge Exp $
+ * $Id: win32_compatibility.h,v 1.4 2008/06/04 22:58:37 gareuselesinge Exp $
  * This file is part of liberopops (http://liberopops.sf.net)                 *
  * This file is distributed under the terms of GNU GPL license.               *
  ******************************************************************************/
@@ -92,7 +92,8 @@ int win_vsnprintf(const char *format, va_list ap);
 				__result = vsnprintf(a,b,c,d);	\
 			__result; }))
 
-int inet_aton(const char *cp, struct in_addr *inp);
+#define inet_aton(a,b) inet_aton_w32(a,b)
+int inet_aton_w32(const char *cp, struct in_addr *inp);
 
 #endif
 
