@@ -16,6 +16,13 @@
 -- in LUA, so use the <tt>__</tt> for attributes. See the xml2table 
 -- documentation for more infos about Txml.
 
+MODULE_VERSION = "0.0.1"
+MODULE_NAME = "table2xml"
+MODULE_REQUIRE_VERSION = "0.2.0"
+MODULE_LICENSE = "GNU/GPL"
+MODULE_URL = "http://www.freepops.org/download.php?module=table2xml.lua"
+MODULE_HOMEPAGE = "http://www.freepops.org/"
+
 local Private = {}
 
 --============================================================================--
@@ -143,7 +150,7 @@ end
 -- extern function
 --==========================================================================--
 
-module("table2xml")
+module("table2xml",package.seeall)
 
 ---
 -- Txml2xml conversion.
