@@ -21,7 +21,7 @@ function basename(s)
 	end
 end
 
-if table.getn(arg) < 2 then
+if #arg < 2 then
 	print([[
 	cvs2changelog.lua should be called with 2 aguments:
 	 1) the number of days
@@ -39,6 +39,7 @@ f = io.open(file,"r")
 
 log = {}
 current = {}
+passed = {}
 status = "nothing"
 for l in f:lines() do
 	local _,_,x = string.find(l,"^(revision)")
@@ -46,9 +47,16 @@ for l in f:lines() do
 	if x ~= nil and status == "nothing" then
 		table.insert(log,current)
 		status = "revision"
+
+		-- print(table.concat(passed,'\n'))
+		-- table.foreach(current, print)
+
+		passed = {}
 		current = {}
 	end
 
+	table.insert(passed, l)
+
 	if status == "revision" then
 		local _,_,r = string.find(l,"^revision ([%d%.]+)")
 		current.revision = r
@@ -73,7 +81,7 @@ table.insert(log,current)
 
 table.foreach(log,function(_,v)
 	if v.revision ~= nil then
-		print("- " .. basename(arg[2]) .. ": "	.. v.comment ..
+		print("- " .. arg[2] .. ": "	.. v.comment ..
 			" ("..v.author..")")
 	end
 end)
