@@ -1,5 +1,5 @@
 /******************************************************************************
- * $Id: engine.c,v 1.27 2006/01/15 19:43:15 gareuselesinge Exp $
+ * $Id: engine.c,v 1.29 2007/01/13 22:36:25 gareuselesinge Exp $
  * This file is part of FreePOPs (http://www.freepops.org)                    *
  * This file is distributed under the terms of GNU GPL license.               *
  ******************************************************************************/
@@ -119,7 +119,7 @@ free(ans);
 lua_State* bootstrap(const char * username, struct popstate_t* p){
 	int rc = POPSERVER_ERR_UNKNOWN;
 	lua_State* l;
-	l = luabox_genbox(LUABOX_STANDARD|LUABOX_LOG|LUABOX_LUAFILESYSTEM);
+	l = luabox_genbox(LUABOX_LOG|LUABOX_LUAFILESYSTEM);
 
 	putenv("FREEPOPSLUA_PATH_UNOFFICIAL="FREEPOPSLUA_PATH_UNOFFICIAL);
 	putenv("FREEPOPS_VERSION="VERSION);
@@ -160,10 +160,15 @@ lua_State* bootstrap(const char * username, struct popstate_t* p){
 				return NULL;
 				}
 			putenv("FREEPOPSLUA_PATH=./");
+			putenv("FREEPOPSLUA_PATH_UPDATES=./");
 			}
 		putenv("FREEPOPSLUA_PATH=src/lua/");
+		putenv("FREEPOPSLUA_CPATH=updater-ui/fltk/");
+		putenv("FREEPOPSLUA_PATH_UPDATES=src/lua_updates/");
 	} else	{
 		putenv("FREEPOPSLUA_PATH="FREEPOPSLUA_PATH);
+		putenv("FREEPOPSLUA_CPATH="FREEPOPSLUA_CPATH);
+		putenv("FREEPOPSLUA_PATH_UPDATES="FREEPOPSLUA_PATH_UPDATES);
 	}
 
 	rc = lua_pcall(l, 0, LUA_MULTRET, 0);
