@@ -1,5 +1,5 @@
 /******************************************************************************
- * $Id: freepops.c,v 1.37 2007/05/11 11:46:40 gareuselesinge Exp $
+ * $Id: freepops.c,v 1.41 2007/10/27 13:17:24 gareuselesinge Exp $
  * This file is part of FreePOPs (http://www.freepops.org)                    *
  * This file is distributed under the terms of GNU GPL license.               *
  ******************************************************************************/
@@ -60,6 +60,8 @@
 #include "engine.h"
 #include "altsocklib.h"
 #include "regularexp.h"
+#include "stats.h"
+#include "session.h"
 
 #include "lua.h"
 #include "luay.h"
@@ -100,30 +102,37 @@ HIDDEN void add_to_args(const char * arg){
 }
 
 /*** usage ********************************************************************/
-#define GETOPT_STRING "-b:p:P:A:u:t:l:s:dhVvwknx:e:"
-HIDDEN  struct option opts[] = { { "bind", required_argument, NULL, 'b' },
-				 { "port", required_argument, NULL, 'p' },
-				 { "proxy", required_argument, NULL, 'P' },
-				 { "auth", required_argument, NULL, 'A' },
-				 { "useragent", required_argument, NULL, 'u' },
-				 { "threads", required_argument, NULL, 't' },
-				 { "help" , no_argument , NULL, 'h'},
-				 { "version" , no_argument , NULL , 'V'},
-				 { "verbose", no_argument, NULL, 'v' },
-				 { "veryverbose", no_argument, NULL, 'w' },
-				 { "logmode", required_argument, NULL, 'l' },
-				 { "daemonize", no_argument, NULL, 'd' },
-				 { "suid", required_argument, NULL, 's' },
-				 { "kill", no_argument, NULL, 'k' },
-				 { "no-pid-file", no_argument, NULL, 'n' },
-				 { "toxml", required_argument, NULL, 'x' },
-				 { "force-proxy-auth-type", 
-					 required_argument, NULL, 1000 },
-				 { "fpat", 
-					 required_argument, NULL, 1000 },
-				 { "no-icon",no_argument, NULL, 1001},
-				 { "execute",required_argument, NULL, 'e'},
-	                         { NULL, 0, NULL, 0 } };
+#define GETOPT_STRING "-b:p:P:A:u:t:l:s:dhVvwknx:e:c:"
+HIDDEN  struct option opts[] = { 
+	{ "bind", required_argument, NULL, 'b' },
+	{ "port", required_argument, NULL, 'p' },
+	{ "proxy", required_argument, NULL, 'P' },
+	{ "auth", required_argument, NULL, 'A' },
+	{ "useragent", required_argument, NULL, 'u' },
+	{ "threads", required_argument, NULL, 't' },
+	{ "help" , no_argument , NULL, 'h'},
+	{ "version" , no_argument , NULL , 'V'},
+	{ "verbose", no_argument, NULL, 'v' },
+	{ "veryverbose", no_argument, NULL, 'w' },
+	{ "logmode", required_argument, NULL, 'l' },
+	{ "daemonize", no_argument, NULL, 'd' },
+	{ "suid", required_argument, NULL, 's' },
+	{ "kill", no_argument, NULL, 'k' },
+	{ "no-pid-file", no_argument, NULL, 'n' },
+	{ "toxml", required_argument, NULL, 'x' },
+	{ "force-proxy-auth-type", required_argument, NULL, 1000 },
+	{ "fpat", required_argument, NULL, 1000 },
+	{ "no-icon",no_argument, NULL, 1001},
+	{ "execute",required_argument, NULL, 'e'},
+	{ "conffile",required_argument, NULL, 'c'},
+	{ "statistics-all",no_argument, NULL, 1002},
+	{ "statistics-session-created",no_argument, NULL, 1003},
+	{ "statistics-session-ok",no_argument, NULL, 1004},
+	{ "statistics-session-err",no_argument, NULL, 1005},
+	{ "statistics-connection-established",no_argument, NULL, 1006},
+	{ "statistics-cookies",no_argument, NULL, 1007},
+	{ "statistics-pwd-file",required_argument, NULL, 1008},
+	{ NULL, 0, NULL, 0 } };
 
 HIDDEN void usage(const char *progname) {
 	fprintf(stderr, 
@@ -139,7 +148,15 @@ HIDDEN void usage(const char *progname) {
 "\t\t\t[-l|--logmode (syslog|filename|stdout)]\n"
 "\t\t\t[-x|--toxml file]\n"
 "\t\t\t[-e|--execute scriptfile [args...]]\n"
+"\t\t\t[-c|--conffile configurationfile]\n"
 "\t\t\t[--fpat|--force-proxy-auth-type (basic|digest|ntlm|gss)]\n"
+"\t\t\t[--statistics-all]\n"
+"\t\t\t[--statistics-session-created]\n"
+"\t\t\t[--statistics-session-ok]\n"
+"\t\t\t[--statistics-session-err]\n"
+"\t\t\t[--statistics-connection-established]\n"
+"\t\t\t[--statistics-cookies]\n"
+"\t\t\t[--statistics-pwd-file filename]\n"
 #if defined(WIN32)
 "\t\t\t[--no-icon]\n"
 #endif
@@ -416,6 +433,27 @@ void my_putenv(const char* a, const char* b) {
 	putenv(tmp);
 }
 
+void load_pwd_file(const char *varname, const char *pwdfilename){
+	FILE* f = fopen(pwdfilename,"r");
+	if (f != NULL){
+		char buff[100];
+		size_t got;
+		got = fread(buff,1,99,f);
+		if (! feof(f)) {
+			fprintf(stderr, "Error reading %s.\n", pwdfilename);
+			perror("fread");
+			exit(1);
+		} else {
+			buff[got] = '\0';
+			my_putenv(varname,buff);
+		}
+	} else {
+		fprintf(stderr, "Unable to open file '%s' for reading.\n", pwdfilename);
+		perror("fopen");
+		exit(1);	
+	}
+}
+
 /*** THE MAIN HAS YOU *********************************************************/
 #if CRYPTO_IMPLEMENTATION == 1
 	GCRY_THREAD_OPTION_PTHREAD_IMPL;
@@ -428,11 +466,13 @@ int WINAPI WinMain(HINSTANCE hInstance, HINSTANCE hPrevInstance,
                     LPSTR lpszCmdLine, int nCmdShow){
 #endif
 	int res;
+	unsigned long int active_stats=0;
 	int threads_num = MAXTHREADS;
 	unsigned short port = POP3PORT;
 	struct in_addr address;
 	char *useragent = NULL, *proxy = NULL, *proxyauth = NULL, *fpat = NULL;
 	char *script = NULL, *execute_stdout = NULL;
+	char *conffile = NULL, *stats_pwd = NULL;
 
 #if defined(WIN32)	
 	int tray_icon = 1;
@@ -628,9 +668,34 @@ int WINAPI WinMain(HINSTANCE hInstance, HINSTANCE hPrevInstance,
 			for (i=optind;i<argc;i++){
 				add_to_args(argv[i]);
 			}
+		} else if (res == 'c') {
+			free(conffile);
+			conffile=strdup(optarg);
 		} else if (res == 1){
 			/* extra arguments */
 			add_to_args(optarg);
+		} else if (res == 1002) {
+			/* statistics-all */
+			active_stats |= STATS_ALL;
+		} else if (res == 1003) {
+			/* statistics-session-created */
+			active_stats |= STATS_SESSION_CREATED;
+		} else if (res == 1004) {
+			/* statistics-session-ok */
+			active_stats |= STATS_SESSION_OK;
+		} else if (res == 1005) {
+			/* statistics-session-err */
+			active_stats |= STATS_SESSION_ERR;
+		} else if (res == 1006) {
+			/* statistics-connection-established */
+			active_stats |= STATS_CONNECTION_ESTABLISHED;
+		} else if (res == 1007) {
+			/* statistics-cookies */
+			active_stats |= STATS_COOKIES;
+		} else if (res == 1008) {
+			/* statistics-pwd-file */
+			free(stats_pwd);
+			stats_pwd = strdup(optarg);
 		} else {
 			/* unknown param */
 			usage(argv[0]);
@@ -642,15 +707,24 @@ int WINAPI WinMain(HINSTANCE hInstance, HINSTANCE hPrevInstance,
 	
 	srand(time(NULL) + getpid());
 	
+	if (stats_pwd != NULL)
+		load_pwd_file("FREEPOPSLUA_STATS_PWD",stats_pwd);
+	
 	start_logging(logfile,verbose_output);
+	session_init();
 	
 	if(useragent == NULL)
 		useragent = strdup(DEFAULT_USERAGENT);
 	
-	my_putenv("LUA_HTTP_USERAGENT",useragent);
-	my_putenv("LUA_HTTP_PROXY",proxy);
-	my_putenv("LUA_HTTP_PROXYAUTH",proxyauth);
-	my_putenv("LUA_FORCE_PROXY_AUTH_TYPE",fpat);
+	my_putenv("FREEPOPSLUA_HTTP_USERAGENT",useragent);
+	my_putenv("FREEPOPSLUA_HTTP_PROXY",proxy);
+	my_putenv("FREEPOPSLUA_HTTP_PROXYAUTH",proxyauth);
+	my_putenv("FREEPOPSLUA_FORCE_PROXY_AUTH_TYPE",fpat);
+	
+	if (conffile != NULL)
+		my_putenv("FREEPOPSLUA_CONFFILE",conffile);
+
+	stats_activate(active_stats);
 	
 /*** INTERPRETER MODE ***/
 	if (script != NULL){
