@@ -1,7 +1,7 @@
 -- ************************************************************************** --
 --  FreePOPs @--put here domain-- webmail interface
 -- 
---  $Id: davmail.lua,v 1.11 2007/10/21 18:09:05 gareuselesinge Exp $
+--  $Id: davmail.lua,v 1.12 2008/11/24 20:48:13 gareuselesinge Exp $
 -- 
 --  Released under the GNU/GPL license
 --  Written by Enrico Tassi <gareuselesinge@users.sourceforge.net>
@@ -11,7 +11,7 @@ PLUGIN_VERSION = "0.0.6"
 PLUGIN_NAME = "DAVMAIL"
 PLUGIN_REQUIRE_VERSION = "0.2.0"
 PLUGIN_LICENSE = "GNU/GPL"
-PLUGIN_URL = "http://www.freepops.org/download.php?module=owa.lua"
+PLUGIN_URL = "http://www.freepops.org/download.php?module=davmail.lua"
 PLUGIN_HOMEPAGE = "http://www.freepops.org/"
 PLUGIN_AUTHORS_NAMES = {"Enrico Tassi"}
 PLUGIN_AUTHORS_CONTACTS = {"gareuselesinge (at) users (.) sourceforge (.) net"}
