@@ -7,7 +7,7 @@
 
 -- Globals
 --
-PLUGIN_VERSION = "0.0.4"
+PLUGIN_VERSION = "0.0.5a"
 PLUGIN_NAME = "excite"
 PLUGIN_REQUIRE_VERSION = "0.0.99"
 PLUGIN_LICENSE = "GNU/GPL"
@@ -181,9 +181,9 @@ function login()
 	--http://registration.excite.com/excitereg/login.jsp?ref=email&return_url=http://e30.email.excite.com
 		
 	-- seed math.random properly
-	math.randomseed(math.mod(os.time(),37))
+	math.randomseed(math.fmod(os.time(),37))
 	local j = math.random(67)
-	math.randomseed((math.mod((os.time()/j),73)+1)*j)
+	math.randomseed((math.fmod((os.time()/j),73)+1)*j)
 	
 	--get cookie 'uu'
 	--
@@ -338,6 +338,10 @@ function downloadMsg(pstate, msg, nLines, data)
     -- Lines Received - Not really used for anything
     --
     nLinesReceived = 0,
+	
+	-- Buffer of last characters sent to the client.
+	--
+	strBuffer = nil,
   }
 	
   -- Define the callback
@@ -353,6 +357,11 @@ function downloadMsg(pstate, msg, nLines, data)
     return POPSERVER_ERR_NETWORK
   end
 
+  if (cbInfo.strBuffer ~= "\r\n") then
+	log.dbg("Message doesn't end in CRLF, adding to prevent client timeout.")
+	popserver_callback("\r\n\0", data)
+  end
+
   return POPSERVER_ERR_OK
 end
 
@@ -395,6 +404,7 @@ function downloadMsg_cb(cbInfo, data)
 
     -- End the strings properly
     --
+	cbInfo.strBuffer = string.sub(body, -2, -1)
     body = cbInfo.strHack:dothack(body) .. "\0"
 	--log.dbg ("Msg ::" ..body)
     -- Send the data up the stream
