@@ -2,15 +2,15 @@
 --  FreePOPs @foo.xx webmail interface, the plugin made in the tutorial,
 --  see the manal for more infos about this simple example
 -- 
---  $Id: foo.lua,v 1.16 2006/01/26 01:39:18 russell822 Exp $
+--  $Id: foo.lua,v 1.18 2007/01/14 16:49:36 gareuselesinge Exp $
 -- 
 --  Released under the GNU/GPL license
 --  Written by Me <Me@myhouse>
 -- ************************************************************************** --
 
-PLUGIN_VERSION = "0.0.4"
+PLUGIN_VERSION = "0.0.5"
 PLUGIN_NAME = "Foo web mail"
-PLUGIN_REQUIRE_VERSION = "0.0.97"
+PLUGIN_REQUIRE_VERSION = "0.2.0"
 PLUGIN_LICENSE = "GNU/GPL"
 PLUGIN_URL = "http://www.freepops.org/"
 PLUGIN_HOMEPAGE = "http://www.freepops.org"
@@ -103,7 +103,7 @@ function pass(pstate,password)
 	--print("we received this webpage: ".. file)
 
 	-- search the session ID
-	local _,_,id = string.find(file,"session_id=(%w+)")
+	local id = string.match(file,"session_id=(%w+)")
 
 	if id == nil then 
 		return POPSERVER_ERR_AUTH
@@ -174,10 +174,10 @@ function stat(pstate)
 	set_popstate_nummesg(pstate,x:count())
 
 	for i=1,x:count() do
-		local _,_,size = string.find(x:get(0,i-1),"(%d+)")
-		local _,_,size_mult_k = string.find(x:get(0,i-1),"([Kk][Bb])")
-		local _,_,size_mult_m = string.find(x:get(0,i-1),"([Mm][Bb])")
-		local _,_,uidl = string.find(x:get(1,i-1),"check_(%d+)")
+		local size = string.match(x:get(0,i-1),"(%d+)")
+		local size_mult_k = string.match(x:get(0,i-1),"([Kk][Bb])")
+		local size_mult_m = string.match(x:get(0,i-1),"([Mm][Bb])")
+		local uidl = string.match(x:get(1,i-1),"check_(%d+)")
 
 		if size_mult_k ~= nil then
 			size = size * 1024
