@@ -17,7 +17,7 @@
 -- ************************************************************************** --
 --  FreePOPs @libero.it, @inwind.it, @blu.it, @iol.it webmail interface
 --  
---  $Id: libero.lua,v 1.60 2008/05/29 13:36:29 gareuselesinge Exp $
+--  $Id: libero.lua,v 1.65 2008/07/18 09:10:07 gareuselesinge Exp $
 --  
 --  Released under the GNU/GPL license
 --  Written by Enrico Tassi <gareuselesinge@users.sourceforge.net>
@@ -27,7 +27,7 @@
 -- fill them in the right way
 
 -- single string, all required
-PLUGIN_VERSION = "0.2.13"
+PLUGIN_VERSION = "0.2.18"
 PLUGIN_NAME = "Libero.IT"
 PLUGIN_REQUIRE_VERSION = "0.2.0"
 PLUGIN_LICENSE = "GNU/GPL"
@@ -84,10 +84,11 @@ PLUGIN_DESCRIPTIONS = {
 -- expressions), mlex expressions, mlex get expressions.
 -- 
 local libero_string = {
+	site = ".libero.it",
 	-- The uri the browser uses when you click the "login" button
-	login_url = "http://wpop%d%s/email.php",		
-	login_post = "dominio=%s&"..
-		"LOGIN=%s&PASSWD=%s&choice=%s&Act_Login.x=%d&Act_Login.y=%d",		
+	login_url = "https://login.libero.it/logincheck.php",		
+	login_post = "LOGINID=%s&PASSWORD=%s&AJAX=0&"..
+		"RET_URL=http://wpop%d%s/email.php&SERVICE_ID=old_email",
 	-- This is the capture to get the session ID from the login-done webpage
 	sessionC = "/cgi%-bin/webmail%.[ce][gx][ie]%?ID=([a-zA-Z0-9_%-]+)&",
 	-- This is the mlex expression to interpret the message list page.
@@ -134,14 +135,6 @@ local libero_string = {
 	delete_next = "&Msg_Sel_%d=%s"
 }
 
--- this table contains the realtion between the mail address domain, the
--- webmail domain name and the mailbox domain
-local libero_domain = {
-	["libero.it"] = { website=".libero.it",        choice="libero" },
-	["inwind.it"] = { website=".inwind.libero.it", choice="inwind" },
-	["iol.it"]    = { website=".iol.libero.it",    choice="iol"    },
-	["blu.it"]    = { website=".blu.libero.it",    choice="blu"    }
-}
 
 -- ************************************************************************** --
 --  State
@@ -172,13 +165,6 @@ function check_range(pstate,msg)
 	return msg >= 1 and msg <= n
 end
 
---------------------------------------------------------------------------------
--- Checks the validity of a domain
---
-function check_domain(domain)
-	return 	libero_domain[domain] ~= nil
-end
-
 --------------------------------------------------------------------------------
 -- Serialize the internal_state
 --
@@ -221,22 +207,21 @@ function libero_login()
 	local password = internal_state.password
 	local popnumber = math.fmod(os.time(),15) + 1  -- == random(1..15)
 	local domain = internal_state.domain
-	local site = libero_domain[domain].website
-	local choice = libero_domain[domain].choice
+	local site = libero_string.site 
 	local user = internal_state.name
-	if internal_state.domain ~= "libero.it" then
-		user = user .. "@" .. domain
-	end
 	local x,y = math.fmod(os.time(),16),math.fmod(os.time()*2,16)
-	local uri = string.format(libero_string.login_url,popnumber,site)
+	local uri = libero_string.login_url
         log.dbg("Using webserver " .. uri);
 	local post= string.format(libero_string.login_post,
-	            domain,user,password,choice,x,y)
+		user .. "@" .. domain,password,popnumber,site)
 	
 	-- the browser must be preserved
 	internal_state.b = browser.new()
 	local b = internal_state.b
 	--b:verbose_mode()
+	b:ssl_init_stuff()
+
+	-- load some cookies
 	
 	-- the functions for do_until
 	-- extract_f uses the support function to extract a capture specifyed 
@@ -298,12 +283,6 @@ function user(pstate,username)
 		domain = "libero.it"
 	end
 
-	-- check if the domain is valid
-	if not check_domain(domain) then
-		-- dead code
-		return POPSERVER_ERR_AUTH
-	end
-	
 	-- save domain and name
 	internal_state.domain = domain
 	internal_state.name = name
