@@ -7,7 +7,7 @@
 
 -- Globals
 --
-PLUGIN_VERSION = "0.0.2f"
+PLUGIN_VERSION = "0.0.2g"
 PLUGIN_NAME = "mail2world.com"
 PLUGIN_REQUIRE_VERSION = "0.2.0"
 PLUGIN_LICENSE = "GNU/GPL"
@@ -478,7 +478,7 @@ function quit_update(pstate)
 
       -- Send out in a batch of 5
       --
-      if math.mod(dcnt, 25) == 0 then
+      if math.fmod(dcnt, 25) == 0 then
         log.dbg("Sending Delete URL: " .. cmdUrl .. "\n")
         local body, err = browser:post_uri(cmdUrl, post)
        
