@@ -7,7 +7,7 @@
 
 -- Globals
 --
-PLUGIN_VERSION = "0.0.3b"
+PLUGIN_VERSION = "0.0.3c"
 PLUGIN_NAME = "netscape.net"
 PLUGIN_REQUIRE_VERSION = "0.2.0"
 PLUGIN_LICENSE = "GNU/GPL"
@@ -602,7 +602,7 @@ function quit_update(pstate)
 
       -- Send out in a batch of 5
       --
-      if math.mod(dcnt, 5) == 0 then
+      if math.fmod(dcnt, 5) == 0 then
         local cmdCookie = browser:get_cookie('COMMAND')
         cmdUrl = cmdUrl .. "&cmdnum=" .. (cmdCookie.value or "")
         log.dbg("Sending Delete URL: " .. cmdUrl .. "\n")
