@@ -1,7 +1,7 @@
 -- ************************************************************************** --
 --  FreePOPs @virgilio.it, @tin.it webmail interface
 --  
---  $Id: tin.lua,v 1.90 2007/11/16 14:13:40 nvhs Exp $
+--  $Id: tin.lua,v 1.95 2008/04/03 22:34:35 gareuselesinge Exp $
 --  
 --  Released under the GNU/GPL license
 --  Written by Enrico Tassi <gareuselesinge@users.sourceforge.net>
@@ -9,7 +9,7 @@
 
 
 -- these are used in the init function
-PLUGIN_VERSION = "0.2.11e"
+PLUGIN_VERSION = "0.2.11h"
 PLUGIN_NAME = "Tin.IT"
 PLUGIN_REQUIRE_VERSION = "0.2.0"
 PLUGIN_LICENSE = "GNU/GPL"
@@ -108,11 +108,7 @@ local tin_string = {
 	save_sl = "http://%s/cp/ps/Mail/Email"..
 		"?sh=&fp=%s&d=%s&sd=&sc=&an=%s&u=%s&"..
 		"uid=&t=%s&style=&l=it&s=%s&sl=%d",	
-	body_start = [[
-</script>	
-			<br>
-			<br>
-          </div>]],
+	body_start = [[%s-</script>%s-<br>%s-<br>%s-</div>]],
 	body_end = [[</div></td>%s*<td width="5"><spacer type="block" width="5" height="1"></td>%s*<td width="1" bgcolor="#FFFFFF"><spacer type="block" width="1" height="1"></td>%s*</tr>%s*</table>%s*<!%-%-FINE TABELLA LISTING MAIL%-%->]],
 	 attachE = ".*<a.*href='/cp/ps/Mail/ViewAttachment>.*<img>.*</a>",
 	 attachG = "O<X>O<O>X<O>",
@@ -663,7 +659,7 @@ function stat(pstate)
 				end
 				-- there should be links before and after 
 				-- the list
-				if math.mod(how_many_refs, 2) ~= 0 then
+				if math.fmod(how_many_refs, 2) ~= 0 then
 					log.error_print(
 						"Error in counting list_href")
 					return true
@@ -791,7 +787,8 @@ function tin_parse_webmessage(wherearewe, data)
 	-- patch by galdom
 	head = string.gsub(head, "\\&#39;", "'")
 	head = string.gsub(head, "&amp;", "&")
-
+	
+	head=string.gsub(head,"[Cc][Oo][Nn][Tt][Ee][Nn][Tt]%-[Tt][Rr][Aa][Nn][sS][fF][ee][Rr]%-[eE][Nn][Cc][Oo][dD][Ii][Nn][Gg].-[;\n ]","")		
 	
 	-- locate body
 	local _, begin_body = string.find(data, tin_string.body_start)
@@ -955,7 +952,7 @@ function retr(pstate,msg,data)
 	local wherearewe = add_webmail_in_front(b:wherearewe())
 	local head,body,body_html,attach,inlineids = tin_parse_webmessage(wherearewe, f)
 	local cb = mimer.callback_mangler(common.retr_cb(data))
-	head = string.gsub(head,"([Cc][Hh][Aa][Rr][Ss][Ee][Tt]=).-[;\n]","%1\""..ctype.."\"; ")
+	head = string.gsub(head,"([Cc][Hh][Aa][Rr][Ss][Ee][Tt]%s*=).-([;\n])","%1\""..ctype.."\"%2")
 	mimer.pipe_msg(head,body,body_html,"http://"..wherearewe,attach,b,cb,inlineids,ctype)
 		
 	return POPSERVER_ERR_OK
@@ -1021,7 +1018,7 @@ function top(pstate,msg,lines,data)
 	local head,body,body_html,attach,inlineids = tin_parse_webmessage(wherearewe, f)
 	local global = common.new_global_for_top(lines,nil)
 	local cb = mimer.callback_mangler(common.top_cb(global,data,true))
-	head = string.gsub(head,"([Cc][Hh][Aa][Rr][Ss][Ee][Tt]=).-[;\n]","%1\""..ctype.."\"; ")
+	head = string.gsub(head,"([Cc][Hh][Aa][Rr][Ss][Ee][Tt]%s*=).-([;\n])","%1\""..ctype.."\"%2")
 	mimer.pipe_msg(head,body,body_html,"http://"..wherearewe,attach,b,cb,nil,ctype)
 		
 	return POPSERVER_ERR_OK
