@@ -1,5 +1,5 @@
 /******************************************************************************
- * $Id: luabox.c,v 1.12 2008/06/05 14:12:05 gareuselesinge Exp $
+ * $Id: luabox.c,v 1.15 2008/08/18 18:06:37 gareuselesinge Exp $
  * This file is part of FreePOPs (http://www.freepops.org)					*
  * This file is distributed under the terms of GNU GPL license.			   *
  ******************************************************************************/
@@ -38,6 +38,8 @@
 #include "lfs.h"
 #include "dpipe_lua.h"
 #include "stats_lua.h"
+#include "lwel.h"
+#include "lgettext.h"
 
 #include "log.h"
 #define LOG_ZONE "LUABOX"
@@ -63,6 +65,8 @@ static struct entry_t libs[LUABOX_LAST] = {
 	{"lfs","lfs",luaopen_lfs},
 	{"dpipe","dpipe",luaopen_dpipe},
 	{"stats","stats",luaopen_stats},
+	{"wel.core","wel",luaopen_wel_core},
+	{"lgettext","lgettext",luaopen_lgettext},
 };
 
 lua_State* luabox_genbox(unsigned long intial_stuff){
