@@ -1,5 +1,5 @@
 /******************************************************************************
- * $Id: luabox.h,v 1.8 2008/06/04 22:37:06 gareuselesinge Exp $
+ * $Id: luabox.h,v 1.10 2008/08/18 18:06:37 gareuselesinge Exp $
  * This file is part of FreePOPs (http://www.freepops.org)                    *
  * This file is distributed under the terms of GNU GPL license.               *
  ******************************************************************************/
@@ -33,16 +33,19 @@
 #define LUABOX_LUAFILESYSTEM	(1<<12)
 #define LUABOX_DPIPE		(1<<13)
 #define LUABOX_STATS		(1<<14)
+#define LUABOX_WEL		(1<<15)
+#define LUABOX_LGETTEXT		(1<<16)
 
 #define LUABOX_FREEPOPS	(LUABOX_POP3SERVER|LUABOX_MLEX|LUABOX_STRINGHACK|\
 			 LUABOX_SESSION|LUABOX_CURL|LUABOX_SOCKET|\
 			 LUABOX_BASE64|LUABOX_GETDATE|LUABOX_REGULAREXP|\
 			 LUABOX_LXP|LUABOX_LOG|LUABOX_CRYPTO|\
-			 LUABOX_LUAFILESYSTEM|LUABOX_DPIPE|LUABOX_STATS)
+			 LUABOX_LUAFILESYSTEM|LUABOX_DPIPE|LUABOX_STATS|\
+			 LUABOX_WEL|LUABOX_LGETTEXT)
 
 #define LUABOX_FULL (LUABOX_FREEPOPS)
 
-#define LUABOX_LAST 15
+#define LUABOX_LAST 17
 
 //! generates a luaVM loading initial_stuff libraries
 lua_State* luabox_genbox(unsigned long intial_stuff);
