@@ -1,5 +1,5 @@
 /******************************************************************************
- * $Id: main.cxx,v 1.5 2008/06/11 19:23:25 gareuselesinge Exp $
+ * $Id: main.cxx,v 1.7 2008/08/18 18:06:37 gareuselesinge Exp $
  * This file is part of FreePOPs (http://www.freepops.org)                    *
  * This file is distributed under the terms of GNU GPL license.               *
  ******************************************************************************/
@@ -17,10 +17,13 @@
 #include <lua.hpp>
 #include <libintl.h>
 #include <locale.h>
+#include <string.h>
 
 #include "updater.h"
 #include "linker.h"
 
+static char fp [10];
+
 static int updater_run(lua_State* l){
 	setlocale(LC_MESSAGES, "");
 	#ifdef WIN32
@@ -32,7 +35,8 @@ static int updater_run(lua_State* l){
 	
 	Fl_Double_Window* win = make_main_window();
 	updater_init(l);
-	char* argv[] = {"freepops"};
+	strncpy(fp, "freepops", 10);
+	char *argv[] = {fp,fp};
 	win->show(1, argv);
 	lua_pushnumber(l,Fl::run());
 	return 1;
